@@ -188,7 +188,7 @@ proxy_get_password (EAccount *account,
 	CamelNetworkSecurityMethod security_method;
 	const gchar *poa_address;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (account->source->url, NULL);
 	if (url == NULL)
@@ -216,7 +216,7 @@ proxy_get_password (EAccount *account,
 
 	key = g_strdup_printf ("groupwise://%s@%s/", url->user, poa_address);
 
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, poa_address, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, poa_address, soap_port);
 
 	failed_auth = "";
 
@@ -244,7 +244,7 @@ proxy_login_get_cnc (EAccount *account,
 	const gchar *failed_auth;
 	gchar *uri = NULL, *key = NULL, *prompt = NULL, *password = NULL;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 	gboolean remember;
 
 	url = camel_url_new (account->source->url, NULL);
@@ -270,7 +270,7 @@ proxy_login_get_cnc (EAccount *account,
 		scheme = "https";
 
 	key = g_strdup_printf ("groupwise://%s@%s/", url->user, url->host);
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, url->host, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, url->host, soap_port);
 
 	failed_auth = "";
 	cnc = NULL;
@@ -378,10 +378,10 @@ proxy_soap_login (gchar *email,
 		CamelService *service;
 
 		parent = camel_url_new (e_account_get_string (srcAccount, E_ACCOUNT_SOURCE_URL), NULL);
-		parent_source_url = camel_url_to_string (parent, CAMEL_URL_HIDE_PASSWORD);
+		parent_source_url = camel_url_to_string (parent, 0);
 		uri = camel_url_copy (parent);
 		camel_url_set_user (uri, name);
-		proxy_source_url = camel_url_to_string (uri, CAMEL_URL_HIDE_PASSWORD);
+		proxy_source_url = camel_url_to_string (uri, 0);
 		dstAccount = e_account_new ();
 		e_account_set_string (dstAccount, E_ACCOUNT_ID_ADDRESS, email);
 		dstAccount->enabled = TRUE;
@@ -423,12 +423,12 @@ proxy_login_add_new_store (CamelStore *store,
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	EMailSession *session;
+	EMailBackend *mail_backend;
 	gint permissions = GPOINTER_TO_INT(g_object_get_data ((GObject *)account, "permissions"));
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
-	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+	mail_backend = E_MAIL_BACKEND (shell_backend);
 
 	if (store == NULL)
 		return;
@@ -437,7 +437,7 @@ proxy_login_add_new_store (CamelStore *store,
 		store->mode &= !CAMEL_STORE_WRITE;
 
 	store->flags |= CAMEL_STORE_PROXY;
-	e_mail_store_add (session, store);
+	e_mail_store_add (mail_backend, store);
 }
 
 static void
